==> dcoupon_sdk_flutter_package-1.1.3.tar.gz: lib/src/data/datasources/loyalty_remote_data_source.dart <==
import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/exceptions.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';

import 'package:dcoupon_sdk_flutter_package/src/data/helpers/users_api_helper.dart';

import 'package:dcoupon_sdk_flutter_package/src/data/models/user_add_or_update_loyalty_card_request.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/user_delete_loyalty_card_request.dart';

import 'package:dio/dio.dart';

abstract class LoyaltyRemoteDataSource {
  Future<Either<Failure, dynamic>> getLoyaltyAffiliates();

  Future<Either<Failure, dynamic>> getUserLoyaltyCards();

  Future<Either<Failure, dynamic>> addOrUpdateLoyaltyCard({
    String affiliateApiToken,
    String cardNumber,
  });

  Future<Either<Failure, dynamic>> deleteLoyaltyCard({
    String affiliateApiToken,
    String cardNumber,
  });
}

class LoyaltyRemoteDataSourceImpl implements LoyaltyRemoteDataSource {
  Dio dio = Dio();

  @override
  Future<Either<Failure, dynamic>> getLoyaltyAffiliates() async {
    dio.options.headers = UsersApiHelper.buildHeaders(
      userAuthentication: false,
    );

    try {
      final response = await dio.get(
        UsersApiHelper.getLoyaltyAffiliatesUrl(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> getUserLoyaltyCards() async {
    dio.options.headers = UsersApiHelper.buildHeaders();

    try {
      final response = await dio.get(
        UsersApiHelper.getUserLoyaltyCardsUrl(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> addOrUpdateLoyaltyCard({
    String affiliateApiToken,
    String cardNumber,
  }) async {
    dio.options.contentType = Headers.jsonContentType;

    dio.options.headers = UsersApiHelper.buildHeaders();

    final userAddOrUpdateLoyaltyCardRequest = UserAddOrUpdateLoyaltyCardRequest(
      affiliateApiToken: affiliateApiToken,
      cardNumber: cardNumber,
    );

    try {
      final response = await dio.post(
        UsersApiHelper.addOrUpdateLoyaltyCardUrl(),
        data: userAddOrUpdateLoyaltyCardRequest.toJson(),
      );

      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> deleteLoyaltyCard({
    String affiliateApiToken,
    String cardNumber,
  }) async {
    dio.options.contentType = Headers.jsonContentType;

    dio.options.headers = UsersApiHelper.buildHeaders();

    final userDeleteLoyaltyCardRequest = UserDeleteLoyaltyCardRequest(
      affiliateApiToken: affiliateApiToken,
      cardNumber: cardNumber,
    );

    try {
      final response = await dio.delete(
        UsersApiHelper.deleteLoyaltyCardUrl(),
        data: userDeleteLoyaltyCardRequest.toJson(),
      );

      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }
}

==> dcoupon_sdk_flutter_package-4.0.1.tar.gz: lib/src/data/datasources/loyalty_remote_data_source.dart <==
import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/exceptions.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';

import 'package:dcoupon_sdk_flutter_package/src/data/helpers/users_api_helper.dart';

import 'package:dcoupon_sdk_flutter_package/src/data/models/user_add_or_update_loyalty_card_request.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/user_delete_loyalty_card_request.dart';

import 'package:dio/dio.dart';

abstract class LoyaltyRemoteDataSource {
  Future<Either<Failure, dynamic>> getLoyaltyAffiliates();

  Future<Either<Failure, dynamic>> getUserLoyaltyCards();

  Future<Either<Failure, dynamic>> addOrUpdateLoyaltyCard({
    String? affiliateApiToken,
    String? cardNumber,
  });

  Future<Either<Failure, dynamic>> deleteLoyaltyCard({
    String? affiliateApiToken,
    String? cardNumber,
  });
}

class LoyaltyRemoteDataSourceImpl implements LoyaltyRemoteDataSource {
  Dio dio = Dio()..interceptors.addAll(ConfigReader.dioInterceptors);

  @override
  Future<Either<Failure, dynamic>> getLoyaltyAffiliates() async {
    dio.options.headers = UsersApiHelper.buildHeaders(
      userAuthentication: false,
    );

    try {
      final response = await dio.get(
        UsersApiHelper.getLoyaltyAffiliatesUrl(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.response) {
        return Left(ServerFailure(httpStatus: e.response!.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> getUserLoyaltyCards() async {
    dio.options.headers = UsersApiHelper.buildHeaders();

    try {
      final response = await dio.get(
        UsersApiHelper.getUserLoyaltyCardsUrl(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.response) {
        return Left(ServerFailure(httpStatus: e.response!.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> addOrUpdateLoyaltyCard({
    String? affiliateApiToken,
    String? cardNumber,
  }) async {
    dio.options.contentType = Headers.jsonContentType;

    dio.options.headers = UsersApiHelper.buildHeaders();

    final userAddOrUpdateLoyaltyCardRequest = UserAddOrUpdateLoyaltyCardRequest(
      affiliateApiToken: affiliateApiToken,
      cardNumber: cardNumber,
    );

    try {
      final response = await dio.post(
        UsersApiHelper.addOrUpdateLoyaltyCardUrl(),
        data: userAddOrUpdateLoyaltyCardRequest.toJson(),
      );

      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.response) {
        return Left(ServerFailure(httpStatus: e.response!.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> deleteLoyaltyCard({
    String? affiliateApiToken,
    String? cardNumber,
  }) async {
    dio.options.contentType = Headers.jsonContentType;

    dio.options.headers = UsersApiHelper.buildHeaders();

    final userDeleteLoyaltyCardRequest = UserDeleteLoyaltyCardRequest(
      affiliateApiToken: affiliateApiToken,
      cardNumber: cardNumber,
    );

    try {
      final response = await dio.delete(
        UsersApiHelper.deleteLoyaltyCardUrl(),
        data: userDeleteLoyaltyCardRequest.toJson(),
      );

      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.response) {
        return Left(ServerFailure(httpStatus: e.response!.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }
}
